JavaConnection

Struct JavaConnection 

pub struct JavaConnection {
    outgoing_packets: UnboundedSender<OutboundPacket>,
    cancel_token: CancellationToken,
    compression: Option<CompressionInfo>,
    network_writer: JavaNetworkWriter,
    id: u64,
    player: Weak<Player>,
    keep_alive_tracker: SyncMutex<KeepAliveTracker>,
    latency: SyncMutex<u32>,
}
A connection to a Java client.

Fields

outgoing_packets: UnboundedSender<OutboundPacket>cancel_token: CancellationTokencompression: Option<CompressionInfo>network_writer: JavaNetworkWriterid: u64player: Weak<Player>keep_alive_tracker: SyncMutex<KeepAliveTracker>latency: SyncMutex<u32>

Implementations

Source

impl JavaConnection

pub const fn new( outgoing_packets: UnboundedSender<OutboundPacket>, cancel_token: CancellationToken, compression: Option<CompressionInfo>, network_writer: JavaNetworkWriter, id: u64, player: Weak<Player>, ) -> Self

Creates a new JavaConnection.

async fn write_packet_now( &self, packet: &EncodedPacket, ) -> Result<(), PacketError>

async fn release_network_writer(&self)

pub fn tick(&self)

Ticks the connection.

fn keep_connection_alive(&self)

fn handle_keep_alive(&self, packet: SKeepAlive)

Handles a keep alive packet.

pub fn latency(&self) -> i32

Returns the current latency in milliseconds. This is a smoothed average calculated from keep-alive round-trip times.

pub fn disconnect(&self, reason: impl Into<TextComponent>)

Disconnects the client.

pub fn send_packet<P: ClientPacket>(&self, packet: P)

Sends a packet to the client.

Panics
  • If the packet fails to be encoded.
  • If the packet fails to be sent through the channel.
pub fn send_encoded_packet(&self, packet: EncodedPacket)

Sends an encoded packet to the client.

Panics
  • If the packet fails to be sent through the channel.
pub fn close(&self)

Closes the connection.

pub fn closed(&self) -> bool

Returns whether the connection is closed.

pub async fn wait_for_close(&self)

Waits for the connection to be closed.

const fn can_process_before_join(packet_id: i32) -> bool

const fn can_process_during_domain_handshake(packet_id: i32) -> bool

fn process_packet( &self, packet: RawPacket, player: Arc<Player>, server: &Server, ) -> Result<(), PacketError>

Decodes and dispatches one packet received from the client.

fn decode_domain_gated_packet( packet: RawPacket, player: &Player, ) -> Result<Option<DecodedPlayPacket>, PacketError>

fn decode_play_packet( packet: RawPacket, ) -> Result<DecodedPlayPacket, PacketError>

fn handle_immediate_packet(&self, packet: ImmediatePlayPacket, player: &Player)

pub async fn listener( &self, reader: TCPNetworkDecoder<BufReader<OwnedReadHalf>>, server: Arc<Server>, )

Listens for packets from the client.

pub async fn sender(&self, sender_recv: UnboundedReceiver<OutboundPacket>)

Sends packets to the client.

async fn write_queued_disconnect( &self, sender_recv: &mut UnboundedReceiver<OutboundPacket>, )